==> vue-slider-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/slider/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import "@dft-vue-2-opentiny/vue-theme-mobile/slider/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["update:modelValue", "change", "start", "stop"],
  props: [].concat(props, ["modelValue", "disabled", "max", "min", "vertical", "step", "numPages", "showTip", "showInput", "height", "range", "formatTooltip"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticStyle: {
      "position": "relative"
    }
  }, [_c("div", {
    class: ["tiny-mobile-slider", {
      "tiny-mobile-slider__vertical": _vm.vertical,
      disabled: _vm.disabled
    }],
    style: {
      height: _vm.vertical ? _vm.height : ""
    },
    on: {
      "touchstart": _vm.bindMouseDown
    }
  }, [_c("div", {
    class: ["tiny-mobile-slider__range", _vm.vertical ? "tiny-mobile-slider__down" : "tiny-mobile-slider__left"],
    style: _vm.state.barStyle
  }), _vm.state.leftBtnShow ? _c("div", {
    staticClass: "tiny-mobile-slider__handle",
    class: {
      "handle-focus": _vm.state.activeIndex === 0
    },
    style: _vm.state.leftBtnStyle,
    attrs: {
      "tabindex": "0"
    },
    on: {
      "mouseenter": _vm.displayTip,
      "mouseleave": _vm.hideTip,
      "keydown": _vm.bindKeyDown
    }
  }) : _vm._e(), _vm.state.rightBtnShow ? _c("div", {
    staticClass: "tiny-mobile-slider__handle",
    class: {
      "handle-focus": _vm.state.activeIndex === 1
    },
    style: _vm.state.rightBtnStyle,
    attrs: {
      "tabindex": "0"
    },
    on: {
      "mouseenter": _vm.displayTip,
      "mouseleave": _vm.hideTip,
      "keydown": _vm.bindKeyDown
    }
  }) : _vm._e(), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.showTip && _vm.state.showTip,
      expression: "showTip && state.showTip"
    }],
    staticClass: "tiny-mobile-slider__tips",
    style: _vm.state.tipStyle
  }, [_vm._v(" " + _vm._s(_vm.state.tipValue) + " ")])]), _vm.showInput && !_vm.state.isDouble ? [_c("div", {
    staticClass: "tiny-mobile-slider__input"
  }, [_vm._t("default", [_c("input", {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.state.activeValue,
      expression: "state.activeValue"
    }],
    attrs: {
      "type": "text",
      "disabled": _vm.disabled
    },
    domProps: {
      "value": _vm.state.activeValue
    },
    on: {
      "input": function input($event) {
        if ($event.target.composing)
          return;
        _vm.$set(_vm.state, "activeValue", $event.target.value);
      }
    }
  }), _c("span", {
    staticClass: "tiny-mobile-slider__per"
  }, [_vm._v("%")])], {
    "slotScope": _vm.state.activeValue
  })], 2)] : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-slider-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/slider/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme-mobile/slider/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["update:modelValue", "change", "start", "stop"],
  props: [].concat(props, ["modelValue", "disabled", "max", "min", "vertical", "step", "numPages", "showTip", "showInput", "height", "range", "formatTooltip", "changeCompat"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticStyle: {
      "position": "relative"
    }
  }, [_c("div", {
    class: ["tiny-mobile-slider", {
      "tiny-mobile-slider__vertical": _vm.vertical,
      disabled: _vm.disabled
    }],
    style: {
      height: _vm.vertical ? _vm.height : ""
    },
    on: {
      "touchstart": _vm.bindMouseDown
    }
  }, [_c("div", {
    class: ["tiny-mobile-slider__range", _vm.vertical ? "tiny-mobile-slider__down" : "tiny-mobile-slider__left"],
    style: _vm.state.barStyle
  }), _vm.state.leftBtnShow ? _c("div", {
    staticClass: "tiny-mobile-slider__handle",
    class: {
      "handle-focus": _vm.state.activeIndex === 0
    },
    style: _vm.state.leftBtnStyle,
    attrs: {
      "tabindex": "0"
    },
    on: {
      "mouseenter": _vm.displayTip,
      "mouseleave": _vm.hideTip,
      "keydown": _vm.bindKeyDown
    }
  }) : _vm._e(), _vm.state.rightBtnShow ? _c("div", {
    staticClass: "tiny-mobile-slider__handle",
    class: {
      "handle-focus": _vm.state.activeIndex === 1
    },
    style: _vm.state.rightBtnStyle,
    attrs: {
      "tabindex": "0"
    },
    on: {
      "mouseenter": _vm.displayTip,
      "mouseleave": _vm.hideTip,
      "keydown": _vm.bindKeyDown
    }
  }) : _vm._e(), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.showTip && _vm.state.showTip,
      expression: "showTip && state.showTip"
    }],
    staticClass: "tiny-mobile-slider__tips",
    style: _vm.state.tipStyle
  }, [_vm._v(" " + _vm._s(_vm.state.tipValue) + " ")])]), _vm.showInput && !_vm.state.isDouble ? [_c("div", {
    staticClass: "tiny-mobile-slider__input"
  }, [_vm._t("default", function() {
    return [_c("input", {
      directives: [{
        name: "model",
        rawName: "v-model",
        value: _vm.state.activeValue,
        expression: "state.activeValue"
      }],
      attrs: {
        "type": "text",
        "disabled": _vm.disabled
      },
      domProps: {
        "value": _vm.state.activeValue
      },
      on: {
        "change": _vm.inputOnChange,
        "input": function input($event) {
          if ($event.target.composing) return;
          _vm.$set(_vm.state, "activeValue", $event.target.value);
        }
      }
    }), _c("span", {
      staticClass: "tiny-mobile-slider__per"
    }, [_vm._v("%")])];
  }, {
    "slotScope": _vm.state.activeValue
  })], 2)] : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
